<#
.SYNOPSIS 
Configures SQL Server to cycle error logs nightly

.DESCRIPTION

.PARAMETER $Instance
SQL Server Instance Name.  (server\instance)

.PARAMETER $Owner
Job owner account.

.PARAMETER $Operator
SQL Operator account for notifications.

.OUTPUTS
Text.

.EXAMPLE
Include example text here:
 .\Configure_SQL_Error_Logs.ps1 -SqlServer "SQL01" -Owner "sa"

#>

Param ([string]$Instance,
        [string]$Owner,
		[string]$Operator
)

Import-Module Sqlserver;
	
$svr = new-object ('Microsoft.SqlServer.Management.Smo.Server') $Instance;
$job = new-object ('Microsoft.SqlServer.Management.Smo.Agent.Job') ($svr.JobServer, 'Cycle SQL Error Log');
$job.Description = 'Closes the current error log file and cycles the error log (like a server restart).';
$job.OwnerLoginName = "$Owner";
$job.Create();

$job.EmailLevel =[Microsoft.SqlServer.Management.Smo.Agent.CompletionAction]::OnFailure;
$job.OperatorToEmail = "$Operator";
$job.Alter();

$js = new-object ('Microsoft.SqlServer.Management.Smo.Agent.JobStep') ($job, 'Cycle Error Log');
$js.SubSystem = 'TransactSql';
$js.Command = 'EXEC sp_cycle_errorlog';
$js.OnSuccessAction = 'GoToNextStep';
$js.OnFailAction = 'QuitWithFailure';
$js.JobStepFlags = '4'; #Include step output in history
$js.Create();

$js = new-object ('Microsoft.SqlServer.Management.Smo.Agent.JobStep') ($job, 'Cycle Agent Error Log');
$js.DatabaseName = 'msdb';
$js.SubSystem = 'TransactSql';
$js.Command = 'EXEC sp_cycle_agent_errorlog';
$js.OnSuccessAction = 'QuitWithSuccess';
$js.OnFailAction = 'QuitWithFailure';
$js.JobStepFlags = '4'; #Include step output in history
$js.Create();

$jbsch = new-object ('Microsoft.SqlServer.Management.Smo.Agent.JobSchedule') ($job, 'Daily 12AM');
$jbsch.FrequencyTypes = "Daily";
$jbsch.FrequencySubDayTypes = "Once";
$ts1 = new-object System.TimeSpan(0, 0, 0);
$ts2 = new-object System.TimeSpan(23, 59, 59);
$jbsch.ActiveStartTimeOfDay = $ts1;
$jbsch.ActiveEndTimeOfDay = $ts2;
$jbsch.FrequencyInterval = 1;
$d = new-object System.DateTime(2014, 1, 1);
$jbsch.ActiveStartDate = $d;
$jbsch.Create();