﻿Param ([string]$SQLServiceAcct,
        [string]$SSLCertName
);

$certObj = dir Cert:\LocalMachine\My | where {$_.Subject -match $SSLCertName} | sort $_.NotAfter -Descending | Select -First 1 -ErrorAction Stop;
If ($certObj) {
    write-output "Certificate found with thumbprint: "$certObj.Thumbprint;
    $keyName=(((Get-ChildItem Cert:\LocalMachine\My | Where-Object {$_.Thumbprint -like $certObj.Thumbprint}).PrivateKey).CspKeyContainerInfo).UniqueKeyContainerName
    $keyPath = "C:\ProgramData\Microsoft\Crypto\RSA\MachineKeys\";
    $fullPath=$keyPath+$keyName;
    $acl=Get-Acl -Path $fullPath;
    $newPermission= $SQLServiceAcct,"Read","Allow";
    $accessRule=new-object System.Security.AccessControl.FileSystemAccessRule $newPermission;
    $acl.AddAccessRule($accessRule);
    Try {
        Set-Acl $fullPath $acl;
        write-output "ACL updated";
        }
    Catch {
        write-output "Error updating ACL";
        Exit;
        }
    write-output "Set Encrypted Connection Certificate"
    $regkey = Get-ChildItem -Path "HKLM:\SOFTWARE\Microsoft\Microsoft SQL Server" -Recurse | Where-Object {$_.Name -like "*SuperSocketNetLib"}
    Set-ItemProperty -path $regKey.PSPath -Name Certificate -value ($certObj.Thumbprint).ToLower() ;
    write-output "Enable SSL encryption for SQL client connections."
    $regkey = Get-ChildItem -Path "HKLM:\SOFTWARE\Microsoft\Microsoft SQL Server" -Recurse | Where-Object {$_.Name -like "*SuperSocketNetLib"}
    Set-ItemProperty -path $regKey.PSPath -Name ForceEncryption -value "1";
    }
Else {
    write-output "Unable to find certificate for $SSLCertName";
    write-output "Enable SSL encryption for SQL client connections using Self-Signed Certificate.";
    $regkey = Get-ChildItem -Path "HKLM:\SOFTWARE\Microsoft\Microsoft SQL Server" -Recurse | Where-Object {$_.Name -like "*SuperSocketNetLib"}
    Set-ItemProperty -path $regKey.PSPath -Name ForceEncryption -value "1";
    Exit;
    }

write-output "SQL service must be restarted before setting will take effect."
Restart-Service MSSQLSERVER -Force;
write-output "SQL Service restarted."